"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import prodvana.proto.prodvana.desired_state.model.desired_state_pb2
import prodvana.proto.prodvana.desired_state.model.entity_pb2
import prodvana.proto.prodvana.service.service_config_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class SetDesiredStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_FIELD_NUMBER: builtins.int
    ROLLBACK_FIELD_NUMBER: builtins.int
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    rollback: builtins.bool
    """set if this is a rollback, which will generate a desired state with faster preconditions"""
    def __init__(
        self,
        *,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        rollback: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired_state", b"desired_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state", b"desired_state", "rollback", b"rollback"]) -> None: ...

global___SetDesiredStateReq = SetDesiredStateReq

class ValidateDesiredStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_FIELD_NUMBER: builtins.int
    ROLLBACK_FIELD_NUMBER: builtins.int
    SERVICE_INSTANCE_CONFIGS_FIELD_NUMBER: builtins.int
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    rollback: builtins.bool
    """set if this is a rollback, which will generate a desired state with faster preconditions"""
    @property
    def service_instance_configs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig]:
        """optional, if set, use these service configs instead of fetching from db. can be useful when doing a ValidateApplyParameters followed by a ValidateDesiredState"""
    def __init__(
        self,
        *,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        rollback: builtins.bool = ...,
        service_instance_configs: collections.abc.Iterable[prodvana.proto.prodvana.service.service_config_pb2.CompiledServiceInstanceConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired_state", b"desired_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state", b"desired_state", "rollback", b"rollback", "service_instance_configs", b"service_instance_configs"]) -> None: ...

global___ValidateDesiredStateReq = ValidateDesiredStateReq

class SetDesiredStateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    """unique identifier for the desired state that was just set"""
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id"]) -> None: ...

global___SetDesiredStateResp = SetDesiredStateResp

class GetServiceDesiredStateConvergenceSummaryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___GetServiceDesiredStateConvergenceSummaryReq = GetServiceDesiredStateConvergenceSummaryReq

class StatusExplanations(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    def __init__(
        self,
        *,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status_explanations", b"status_explanations"]) -> None: ...

global___StatusExplanations = StatusExplanations

class DebugLogs(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEBUG_LOGS_FIELD_NUMBER: builtins.int
    @property
    def debug_logs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog]: ...
    def __init__(
        self,
        *,
        debug_logs: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DebugLog] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["debug_logs", b"debug_logs"]) -> None: ...

global___DebugLogs = DebugLogs

class DesiredStateSummary(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class StatusesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class PreconditionStatusesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class StatusExplanationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___StatusExplanations: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___StatusExplanations | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class DebugLogsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___DebugLogs: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___DebugLogs | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class ActionExplanationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class LastUpdateTimestampsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class LastFetchedTimestampsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    class LastAppliedTimestampsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENTITY_GRAPH_FIELD_NUMBER: builtins.int
    STARTING_STATE_FIELD_NUMBER: builtins.int
    LAST_SEEN_STATE_FIELD_NUMBER: builtins.int
    DESIRED_STATE_FIELD_NUMBER: builtins.int
    STATUSES_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMP_FIELD_NUMBER: builtins.int
    REPLACED_TIMESTAMP_FIELD_NUMBER: builtins.int
    PRECONDITION_STATUSES_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    DEBUG_LOGS_FIELD_NUMBER: builtins.int
    ACTION_EXPLANATIONS_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIMESTAMPS_FIELD_NUMBER: builtins.int
    LAST_FETCHED_TIMESTAMPS_FIELD_NUMBER: builtins.int
    LAST_APPLIED_TIMESTAMPS_FIELD_NUMBER: builtins.int
    @property
    def entity_graph(self) -> prodvana.proto.prodvana.desired_state.model.entity_pb2.EntityGraph: ...
    @property
    def starting_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """fields below are deprecated"""
    @property
    def last_seen_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def statuses(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType]:
        """status of the desired state, all its descendents, and the root desired state."""
    @property
    def creation_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_update_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def replaced_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """will only be set if desired state has been replaced"""
    @property
    def precondition_statuses(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState]:
        """State of all preconditions involved in the desired state.
        Key format - "{desired_state_id}-{index}", e.g., "des-0752d6c76a6943abbfcf0515634584ba-0".
        """
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___StatusExplanations]: ...
    @property
    def debug_logs(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___DebugLogs]: ...
    @property
    def action_explanations(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation]: ...
    @property
    def last_update_timestamps(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, google.protobuf.timestamp_pb2.Timestamp]:
        """last_update_timestamp, last_fetched_timestamp, and last_applied_timestamp are only returned for the latest desired state"""
    @property
    def last_fetched_timestamps(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, google.protobuf.timestamp_pb2.Timestamp]: ...
    @property
    def last_applied_timestamps(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, google.protobuf.timestamp_pb2.Timestamp]: ...
    def __init__(
        self,
        *,
        entity_graph: prodvana.proto.prodvana.desired_state.model.entity_pb2.EntityGraph | None = ...,
        starting_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        last_seen_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        statuses: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType] | None = ...,
        creation_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        last_update_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        replaced_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        precondition_statuses: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ConditionState] | None = ...,
        status_explanations: collections.abc.Mapping[builtins.str, global___StatusExplanations] | None = ...,
        debug_logs: collections.abc.Mapping[builtins.str, global___DebugLogs] | None = ...,
        action_explanations: collections.abc.Mapping[builtins.str, prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ActionExplanation] | None = ...,
        last_update_timestamps: collections.abc.Mapping[builtins.str, google.protobuf.timestamp_pb2.Timestamp] | None = ...,
        last_fetched_timestamps: collections.abc.Mapping[builtins.str, google.protobuf.timestamp_pb2.Timestamp] | None = ...,
        last_applied_timestamps: collections.abc.Mapping[builtins.str, google.protobuf.timestamp_pb2.Timestamp] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["creation_timestamp", b"creation_timestamp", "desired_state", b"desired_state", "entity_graph", b"entity_graph", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "replaced_timestamp", b"replaced_timestamp", "starting_state", b"starting_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_explanations", b"action_explanations", "creation_timestamp", b"creation_timestamp", "debug_logs", b"debug_logs", "desired_state", b"desired_state", "entity_graph", b"entity_graph", "last_applied_timestamps", b"last_applied_timestamps", "last_fetched_timestamps", b"last_fetched_timestamps", "last_seen_state", b"last_seen_state", "last_update_timestamp", b"last_update_timestamp", "last_update_timestamps", b"last_update_timestamps", "precondition_statuses", b"precondition_statuses", "replaced_timestamp", b"replaced_timestamp", "starting_state", b"starting_state", "status_explanations", b"status_explanations", "statuses", b"statuses"]) -> None: ...

global___DesiredStateSummary = DesiredStateSummary

class GetDesiredStateConvergenceReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id"]) -> None: ...

global___GetDesiredStateConvergenceReq = GetDesiredStateConvergenceReq

class GetDesiredStateConvergenceSummaryResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARY_FIELD_NUMBER: builtins.int
    @property
    def summary(self) -> global___DesiredStateSummary: ...
    def __init__(
        self,
        *,
        summary: global___DesiredStateSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> None: ...

global___GetDesiredStateConvergenceSummaryResp = GetDesiredStateConvergenceSummaryResp

class GetServiceDesiredStateConvergenceSummaryResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARY_FIELD_NUMBER: builtins.int
    @property
    def summary(self) -> global___DesiredStateSummary: ...
    def __init__(
        self,
        *,
        summary: global___DesiredStateSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> None: ...

global___GetServiceDesiredStateConvergenceSummaryResp = GetServiceDesiredStateConvergenceSummaryResp

class GetServiceLastConvergedStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "service", b"service"]) -> None: ...

global___GetServiceLastConvergedStateReq = GetServiceLastConvergedStateReq

class GetServiceLastConvergedStateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_INSTANCE_STATES_FIELD_NUMBER: builtins.int
    @property
    def service_instance_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ServiceInstanceState]: ...
    def __init__(
        self,
        *,
        service_instance_states: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ServiceInstanceState] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["service_instance_states", b"service_instance_states"]) -> None: ...

global___GetServiceLastConvergedStateResp = GetServiceLastConvergedStateResp

class GetServiceDesiredStateHistoryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    application: builtins.str
    service: builtins.str
    page_token: builtins.str
    page_size: builtins.int
    def __init__(
        self,
        *,
        application: builtins.str = ...,
        service: builtins.str = ...,
        page_token: builtins.str = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "page_size", b"page_size", "page_token", b"page_token", "service", b"service"]) -> None: ...

global___GetServiceDesiredStateHistoryReq = GetServiceDesiredStateHistoryReq

class GetServiceDesiredStateHistoryResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    @property
    def desired_states(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DesiredStateSummary]: ...
    next_page_token: builtins.str
    def __init__(
        self,
        *,
        desired_states: collections.abc.Iterable[global___DesiredStateSummary] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_states", b"desired_states", "next_page_token", b"next_page_token"]) -> None: ...

global___GetServiceDesiredStateHistoryResp = GetServiceDesiredStateHistoryResp

class GetDesiredStateReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id"]) -> None: ...

global___GetDesiredStateReq = GetDesiredStateReq

class GetDesiredStateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_FIELD_NUMBER: builtins.int
    COMPILED_DESIRED_STATE_FIELD_NUMBER: builtins.int
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def compiled_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    def __init__(
        self,
        *,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        compiled_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "desired_state", b"desired_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "desired_state", b"desired_state"]) -> None: ...

global___GetDesiredStateResp = GetDesiredStateResp

class ValidateDesiredStateResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_FIELD_NUMBER: builtins.int
    COMPILED_DESIRED_STATE_FIELD_NUMBER: builtins.int
    @property
    def desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def compiled_desired_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    def __init__(
        self,
        *,
        desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        compiled_desired_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "desired_state", b"desired_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["compiled_desired_state", b"compiled_desired_state", "desired_state", b"desired_state"]) -> None: ...

global___ValidateDesiredStateResp = ValidateDesiredStateResp

class SetManualApprovalReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    REJECT_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    topic: builtins.str
    """string application = 2 [(prodvana.proto.validate.rules).string.min_len = 1];
    string service = 3 [(prodvana.proto.validate.rules).string.min_len = 1];
    string release_channel = 4 [(prodvana.proto.validate.rules).string.min_len = 1];
    """
    reject: builtins.bool
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        topic: builtins.str = ...,
        reject: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "reject", b"reject", "topic", b"topic"]) -> None: ...

global___SetManualApprovalReq = SetManualApprovalReq

class SetManualApprovalResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SetManualApprovalResp = SetManualApprovalResp

class PromoteDeliveryReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    FULL_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    stage: builtins.int
    full: builtins.bool
    source: builtins.str
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        stage: builtins.int = ...,
        full: builtins.bool = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "full", b"full", "source", b"source", "stage", b"stage"]) -> None: ...

global___PromoteDeliveryReq = PromoteDeliveryReq

class PromoteDeliveryResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___PromoteDeliveryResp = PromoteDeliveryResp

class BypassProtectionReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    desired_state_id: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        desired_state_id: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_state_id", b"desired_state_id", "source", b"source"]) -> None: ...

global___BypassProtectionReq = BypassProtectionReq

class BypassProtectionResp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___BypassProtectionResp = BypassProtectionResp



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/release_channel/release_channel_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.prodvana.common_config import maturity_pb2 as prodvana_dot_common__config_dot_maturity__pb2
from prodvana.proto.prodvana.pipelines import pipelines_pb2 as prodvana_dot_pipelines_dot_pipelines__pb2
from prodvana.proto.prodvana.protection import attachments_pb2 as prodvana_dot_protection_dot_attachments__pb2
from prodvana.proto.prodvana.protection import protection_reference_pb2 as prodvana_dot_protection_dot_protection__reference__pb2
from prodvana.proto.prodvana.runtimes import runtimes_config_pb2 as prodvana_dot_runtimes_dot_runtimes__config__pb2
from prodvana.proto.prodvana.workflow import integration_config_pb2 as prodvana_dot_workflow_dot_integration__config__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5prodvana/release_channel/release_channel_config.proto\x12\x18prodvana.release_channel\x1a\x1egoogle/protobuf/duration.proto\x1a prodvana/common_config/env.proto\x1a%prodvana/common_config/maturity.proto\x1a\"prodvana/pipelines/pipelines.proto\x1a%prodvana/protection/attachments.proto\x1a.prodvana/protection/protection_reference.proto\x1a\'prodvana/runtimes/runtimes_config.proto\x1a*prodvana/workflow/integration_config.proto\x1a\x17validate/validate.proto\"\xcd\x01\n\x06Policy\x12n\n\x0b\x64\x65\x66\x61ult_env\x18\x01 \x03(\x0b\x32\x30.prodvana.release_channel.Policy.DefaultEnvEntryB\'\xfa\x42$\x9a\x01!\x18\x01\"\x1dr\x1b\x32\x19^[a-zA-Z_]+[a-zA-Z0-9_]*$\x1aS\n\x0f\x44\x65\x66\x61ultEnvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .prodvana.common_config.EnvValue:\x02\x38\x01\"\xba\x04\n\x14ReleaseChannelConfig\x12\x39\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12\r\n\x05order\x18\x02 \x01(\x03\x12\x32\n\x08maturity\x18\x03 \x01(\x0e\x32 .prodvana.common_config.Maturity\x12\x30\n\x06policy\x18\x04 \x01(\x0b\x32 .prodvana.release_channel.Policy\x12G\n\x08runtimes\x18\x05 \x03(\x0b\x32\x35.prodvana.release_channel.ReleaseChannelRuntimeConfig\x12@\n\x12\x64\x65ploy_annotations\x18\x06 \x01(\x0b\x32$.prodvana.workflow.AnnotationsConfig\x12=\n\rpreconditions\x18\x07 \x03(\x0b\x32&.prodvana.release_channel.Precondition\x12Q\n\x0bprotections\x18\x08 \x03(\x0b\x32<.prodvana.release_channel.ProtectionReleaseChannelAttachment\x12U\n\x17\x63onvergence_protections\x18\t \x03(\x0b\x32\x34.prodvana.protection.ProtectionConvergenceAttachment\"\xed\x01\n\"ProtectionReleaseChannelAttachment\x12:\n\x04name\x18\x01 \x01(\tB,\xfa\x42)r\'\x10\x00\x18?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$\x12?\n\x03ref\x18\x02 \x01(\x0b\x32(.prodvana.protection.ProtectionReferenceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12J\n\tlifecycle\x18\x03 \x03(\x0b\x32(.prodvana.protection.ProtectionLifecycleB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\"\xf1\x03\n\x0cPrecondition\x12]\n\x16release_channel_stable\x18\x01 \x01(\x0b\x32;.prodvana.release_channel.Precondition.ReleaseChannelStableH\x00\x12P\n\x0fmanual_approval\x18\x02 \x01(\x0b\x32\x35.prodvana.release_channel.Precondition.ManualApprovalH\x00\x12H\n\x0b\x63ustom_task\x18\x03 \x01(\x0b\x32\x31.prodvana.release_channel.Precondition.CustomTaskH\x00\x1a\\\n\x14ReleaseChannelStable\x12\x17\n\x0frelease_channel\x18\x01 \x01(\t\x12+\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a\x10\n\x0eManualApproval\x1aT\n\nCustomTask\x12\x11\n\ttask_name\x18\x01 \x01(\t\x12\x33\n\x0b\x63ustom_task\x18\x02 \x01(\x0b\x32\x1e.prodvana.pipelines.CustomTaskB\x0e\n\x0cpreconditionJ\x04\x08\x04\x10\x05R\nprotection\"\xb9\x02\n\x1bReleaseChannelRuntimeConfig\x12<\n\x07runtime\x18\x02 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$\x12:\n\x04name\x18\x03 \x01(\tB,\xfa\x42)r\'\x10\x00\x18?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$\x12S\n\x17\x63ontainer_orchestration\x18\x01 \x01(\x0b\x32\x30.prodvana.runtimes.ContainerOrchestrationRuntimeH\x00\x12=\n\x04type\x18\x04 \x01(\x0e\x32/.prodvana.release_channel.RuntimeConnectionTypeB\x0c\n\ncapability*V\n\x15RuntimeConnectionType\x12\x16\n\x12UNKNOWN_CONNECTION\x10\x00\x12\x16\n\x12LONG_LIVED_COMPUTE\x10\x01\x12\r\n\tEXTENSION\x10\x02\x42TZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channelb\x06proto3')

_RUNTIMECONNECTIONTYPE = DESCRIPTOR.enum_types_by_name['RuntimeConnectionType']
RuntimeConnectionType = enum_type_wrapper.EnumTypeWrapper(_RUNTIMECONNECTIONTYPE)
UNKNOWN_CONNECTION = 0
LONG_LIVED_COMPUTE = 1
EXTENSION = 2


_POLICY = DESCRIPTOR.message_types_by_name['Policy']
_POLICY_DEFAULTENVENTRY = _POLICY.nested_types_by_name['DefaultEnvEntry']
_RELEASECHANNELCONFIG = DESCRIPTOR.message_types_by_name['ReleaseChannelConfig']
_PROTECTIONRELEASECHANNELATTACHMENT = DESCRIPTOR.message_types_by_name['ProtectionReleaseChannelAttachment']
_PRECONDITION = DESCRIPTOR.message_types_by_name['Precondition']
_PRECONDITION_RELEASECHANNELSTABLE = _PRECONDITION.nested_types_by_name['ReleaseChannelStable']
_PRECONDITION_MANUALAPPROVAL = _PRECONDITION.nested_types_by_name['ManualApproval']
_PRECONDITION_CUSTOMTASK = _PRECONDITION.nested_types_by_name['CustomTask']
_RELEASECHANNELRUNTIMECONFIG = DESCRIPTOR.message_types_by_name['ReleaseChannelRuntimeConfig']
Policy = _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), {

  'DefaultEnvEntry' : _reflection.GeneratedProtocolMessageType('DefaultEnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _POLICY_DEFAULTENVENTRY,
    '__module__' : 'prodvana.release_channel.release_channel_config_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.release_channel.Policy.DefaultEnvEntry)
    })
  ,
  'DESCRIPTOR' : _POLICY,
  '__module__' : 'prodvana.release_channel.release_channel_config_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.Policy)
  })
_sym_db.RegisterMessage(Policy)
_sym_db.RegisterMessage(Policy.DefaultEnvEntry)

ReleaseChannelConfig = _reflection.GeneratedProtocolMessageType('ReleaseChannelConfig', (_message.Message,), {
  'DESCRIPTOR' : _RELEASECHANNELCONFIG,
  '__module__' : 'prodvana.release_channel.release_channel_config_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ReleaseChannelConfig)
  })
_sym_db.RegisterMessage(ReleaseChannelConfig)

ProtectionReleaseChannelAttachment = _reflection.GeneratedProtocolMessageType('ProtectionReleaseChannelAttachment', (_message.Message,), {
  'DESCRIPTOR' : _PROTECTIONRELEASECHANNELATTACHMENT,
  '__module__' : 'prodvana.release_channel.release_channel_config_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ProtectionReleaseChannelAttachment)
  })
_sym_db.RegisterMessage(ProtectionReleaseChannelAttachment)

Precondition = _reflection.GeneratedProtocolMessageType('Precondition', (_message.Message,), {

  'ReleaseChannelStable' : _reflection.GeneratedProtocolMessageType('ReleaseChannelStable', (_message.Message,), {
    'DESCRIPTOR' : _PRECONDITION_RELEASECHANNELSTABLE,
    '__module__' : 'prodvana.release_channel.release_channel_config_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.release_channel.Precondition.ReleaseChannelStable)
    })
  ,

  'ManualApproval' : _reflection.GeneratedProtocolMessageType('ManualApproval', (_message.Message,), {
    'DESCRIPTOR' : _PRECONDITION_MANUALAPPROVAL,
    '__module__' : 'prodvana.release_channel.release_channel_config_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.release_channel.Precondition.ManualApproval)
    })
  ,

  'CustomTask' : _reflection.GeneratedProtocolMessageType('CustomTask', (_message.Message,), {
    'DESCRIPTOR' : _PRECONDITION_CUSTOMTASK,
    '__module__' : 'prodvana.release_channel.release_channel_config_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.release_channel.Precondition.CustomTask)
    })
  ,
  'DESCRIPTOR' : _PRECONDITION,
  '__module__' : 'prodvana.release_channel.release_channel_config_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.Precondition)
  })
_sym_db.RegisterMessage(Precondition)
_sym_db.RegisterMessage(Precondition.ReleaseChannelStable)
_sym_db.RegisterMessage(Precondition.ManualApproval)
_sym_db.RegisterMessage(Precondition.CustomTask)

ReleaseChannelRuntimeConfig = _reflection.GeneratedProtocolMessageType('ReleaseChannelRuntimeConfig', (_message.Message,), {
  'DESCRIPTOR' : _RELEASECHANNELRUNTIMECONFIG,
  '__module__' : 'prodvana.release_channel.release_channel_config_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.release_channel.ReleaseChannelRuntimeConfig)
  })
_sym_db.RegisterMessage(ReleaseChannelRuntimeConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZRgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/release_channel'
  _POLICY_DEFAULTENVENTRY._options = None
  _POLICY_DEFAULTENVENTRY._serialized_options = b'8\001'
  _POLICY.fields_by_name['default_env']._options = None
  _POLICY.fields_by_name['default_env']._serialized_options = b'\372B$\232\001!\030\001\"\035r\0332\031^[a-zA-Z_]+[a-zA-Z0-9_]*$'
  _RELEASECHANNELCONFIG.fields_by_name['name']._options = None
  _RELEASECHANNELCONFIG.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _PROTECTIONRELEASECHANNELATTACHMENT.fields_by_name['name']._options = None
  _PROTECTIONRELEASECHANNELATTACHMENT.fields_by_name['name']._serialized_options = b'\372B)r\'\020\000\030?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$'
  _PROTECTIONRELEASECHANNELATTACHMENT.fields_by_name['ref']._options = None
  _PROTECTIONRELEASECHANNELATTACHMENT.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PROTECTIONRELEASECHANNELATTACHMENT.fields_by_name['lifecycle']._options = None
  _PROTECTIONRELEASECHANNELATTACHMENT.fields_by_name['lifecycle']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _RELEASECHANNELRUNTIMECONFIG.fields_by_name['runtime']._options = None
  _RELEASECHANNELRUNTIMECONFIG.fields_by_name['runtime']._serialized_options = b'\372B(r&\020\001\030?2 ^[a-z]([a-z0-9-]*[a-z0-9]){0,1}$'
  _RELEASECHANNELRUNTIMECONFIG.fields_by_name['name']._options = None
  _RELEASECHANNELRUNTIMECONFIG.fields_by_name['name']._serialized_options = b'\372B)r\'\020\000\030?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$'
  _RUNTIMECONNECTIONTYPE._serialized_start=2258
  _RUNTIMECONNECTIONTYPE._serialized_end=2344
  _POLICY._serialized_start=422
  _POLICY._serialized_end=627
  _POLICY_DEFAULTENVENTRY._serialized_start=544
  _POLICY_DEFAULTENVENTRY._serialized_end=627
  _RELEASECHANNELCONFIG._serialized_start=630
  _RELEASECHANNELCONFIG._serialized_end=1200
  _PROTECTIONRELEASECHANNELATTACHMENT._serialized_start=1203
  _PROTECTIONRELEASECHANNELATTACHMENT._serialized_end=1440
  _PRECONDITION._serialized_start=1443
  _PRECONDITION._serialized_end=1940
  _PRECONDITION_RELEASECHANNELSTABLE._serialized_start=1710
  _PRECONDITION_RELEASECHANNELSTABLE._serialized_end=1802
  _PRECONDITION_MANUALAPPROVAL._serialized_start=1804
  _PRECONDITION_MANUALAPPROVAL._serialized_end=1820
  _PRECONDITION_CUSTOMTASK._serialized_start=1822
  _PRECONDITION_CUSTOMTASK._serialized_end=1906
  _RELEASECHANNELRUNTIMECONFIG._serialized_start=1943
  _RELEASECHANNELRUNTIMECONFIG._serialized_end=2256
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/object/meta.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.version import source_metadata_pb2 as prodvana_dot_version_dot_source__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aprodvana/object/meta.proto\x12\x0fprodvana.object\x1a&prodvana/version/source_metadata.proto\"\xb4\x01\n\nObjectMeta\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x16\n\x0e\x63onfig_version\x18\x04 \x01(\t\x12(\n\x06source\x18\x05 \x01(\x0e\x32\x18.prodvana.version.Source\x12\x39\n\x0fsource_metadata\x18\x06 \x01(\x0b\x32 .prodvana.version.SourceMetadataBKZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/objectb\x06proto3')



_OBJECTMETA = DESCRIPTOR.message_types_by_name['ObjectMeta']
ObjectMeta = _reflection.GeneratedProtocolMessageType('ObjectMeta', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTMETA,
  '__module__' : 'prodvana.object.meta_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.object.ObjectMeta)
  })
_sym_db.RegisterMessage(ObjectMeta)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/object'
  _OBJECTMETA._serialized_start=88
  _OBJECTMETA._serialized_end=268
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/notification.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)prodvana/common_config/notification.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\"x\n\x12NotificationConfig\x12?\n\x05slack\x18\x01 \x01(\x0b\x32\x30.prodvana.common_config.NotificationConfig.Slack\x1a!\n\x05Slack\x12\x18\n\x07\x63hannel\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_NOTIFICATIONCONFIG = DESCRIPTOR.message_types_by_name['NotificationConfig']
_NOTIFICATIONCONFIG_SLACK = _NOTIFICATIONCONFIG.nested_types_by_name['Slack']
NotificationConfig = _reflection.GeneratedProtocolMessageType('NotificationConfig', (_message.Message,), {

  'Slack' : _reflection.GeneratedProtocolMessageType('Slack', (_message.Message,), {
    'DESCRIPTOR' : _NOTIFICATIONCONFIG_SLACK,
    '__module__' : 'prodvana.common_config.notification_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.common_config.NotificationConfig.Slack)
    })
  ,
  'DESCRIPTOR' : _NOTIFICATIONCONFIG,
  '__module__' : 'prodvana.common_config.notification_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.NotificationConfig)
  })
_sym_db.RegisterMessage(NotificationConfig)
_sym_db.RegisterMessage(NotificationConfig.Slack)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _NOTIFICATIONCONFIG_SLACK.fields_by_name['channel']._options = None
  _NOTIFICATIONCONFIG_SLACK.fields_by_name['channel']._serialized_options = b'\372B\004r\002\020\001'
  _NOTIFICATIONCONFIG._serialized_start=94
  _NOTIFICATIONCONFIG._serialized_end=214
  _NOTIFICATIONCONFIG_SLACK._serialized_start=181
  _NOTIFICATIONCONFIG_SLACK._serialized_end=214
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/organization/organization_manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.config_writeback import writeback_pb2 as prodvana_dot_config__writeback_dot_writeback__pb2
from prodvana.proto.prodvana.insights import insights_pb2 as prodvana_dot_insights_dot_insights__pb2
from prodvana.proto.prodvana.metrics import metrics_pb2 as prodvana_dot_metrics_dot_metrics__pb2
from prodvana.proto.prodvana.organization import user_metadata_pb2 as prodvana_dot_organization_dot_user__metadata__pb2
from prodvana.proto.prodvana.users import users_pb2 as prodvana_dot_users_dot_users__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0prodvana/organization/organization_manager.proto\x12\x15prodvana.organization\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a)prodvana/config_writeback/writeback.proto\x1a prodvana/insights/insights.proto\x1a\x1eprodvana/metrics/metrics.proto\x1a)prodvana/organization/user_metadata.proto\x1a\x1aprodvana/users/users.proto\x1a\x17validate/validate.proto\"\xd4\x01\n\x10OrganizationInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12H\n\x10writeback_config\x18\x03 \x01(\x0b\x32..prodvana.config_writeback.ConfigWritebackPath\x12\x0c\n\x04slug\x18\x04 \x01(\t\x12\x46\n\ruser_metadata\x18\x05 \x01(\x0b\x32/.prodvana.organization.OrganizationUserMetadata\"\x14\n\x12GetOrganizationReq\"T\n\x13GetOrganizationResp\x12=\n\x0corganization\x18\x01 \x01(\x0b\x32\'.prodvana.organization.OrganizationInfo\"\x83\x01\n\x19GetOrganizationMetricsReq\x12\x33\n\x0fstart_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"]\n\x1aGetOrganizationMetricsResp\x12?\n\x12\x64\x65ployment_metrics\x18\x01 \x01(\x0b\x32#.prodvana.metrics.DeploymentMetrics\"\x1c\n\x1aGetOrganizationInsightsReq\"K\n\x1bGetOrganizationInsightsResp\x12,\n\x08insights\x18\x01 \x03(\x0b\x32\x1a.prodvana.insights.Insight\"\x8a\x01\n\x1cSnoozeOrganizationInsightReq\x12\x31\n\x05\x63lass\x18\x01 \x01(\x0e\x32\x18.prodvana.insights.ClassB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x37\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\"\x1f\n\x1dSnoozeOrganizationInsightResp\"\x1c\n\x1aGetOrganizationMetadataReq\"`\n\x1bGetOrganizationMetadataResp\x12\x41\n\x08metadata\x18\x01 \x01(\x0b\x32/.prodvana.organization.OrganizationUserMetadata\"i\n\x1aSetOrganizationMetadataReq\x12K\n\x08metadata\x18\x01 \x01(\x0b\x32/.prodvana.organization.OrganizationUserMetadataB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\"\x1d\n\x1bSetOrganizationMetadataResp\"&\n\nGetUserReq\x12\x18\n\x07user_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"1\n\x0bGetUserResp\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.prodvana.users.User2\xe1\x08\n\x13OrganizationManager\x12\x82\x01\n\x0fGetOrganization\x12).prodvana.organization.GetOrganizationReq\x1a*.prodvana.organization.GetOrganizationResp\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/organization\x12\x9f\x01\n\x16GetOrganizationMetrics\x12\x30.prodvana.organization.GetOrganizationMetricsReq\x1a\x31.prodvana.organization.GetOrganizationMetricsResp\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/organization/metrics\x12\xa3\x01\n\x17GetOrganizationInsights\x12\x31.prodvana.organization.GetOrganizationInsightsReq\x1a\x32.prodvana.organization.GetOrganizationInsightsResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/organization/insights\x12\xb0\x01\n\x19SnoozeOrganizationInsight\x12\x33.prodvana.organization.SnoozeOrganizationInsightReq\x1a\x34.prodvana.organization.SnoozeOrganizationInsightResp\"(\x82\xd3\xe4\x93\x02\"\x1a /v1/organization/insights/snooze\x12\xa3\x01\n\x17GetOrganizationMetadata\x12\x31.prodvana.organization.GetOrganizationMetadataReq\x1a\x32.prodvana.organization.GetOrganizationMetadataResp\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/organization/metadata\x12\xa6\x01\n\x17SetOrganizationMetadata\x12\x31.prodvana.organization.SetOrganizationMetadataReq\x1a\x32.prodvana.organization.SetOrganizationMetadataResp\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1/organization/metadata:\x01*\x12{\n\x07GetUser\x12!.prodvana.organization.GetUserReq\x1a\".prodvana.organization.GetUserResp\")\x82\xd3\xe4\x93\x02#\x12!/v1/organization/user/{user_id=*}BQZOgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/organizationb\x06proto3')



_ORGANIZATIONINFO = DESCRIPTOR.message_types_by_name['OrganizationInfo']
_GETORGANIZATIONREQ = DESCRIPTOR.message_types_by_name['GetOrganizationReq']
_GETORGANIZATIONRESP = DESCRIPTOR.message_types_by_name['GetOrganizationResp']
_GETORGANIZATIONMETRICSREQ = DESCRIPTOR.message_types_by_name['GetOrganizationMetricsReq']
_GETORGANIZATIONMETRICSRESP = DESCRIPTOR.message_types_by_name['GetOrganizationMetricsResp']
_GETORGANIZATIONINSIGHTSREQ = DESCRIPTOR.message_types_by_name['GetOrganizationInsightsReq']
_GETORGANIZATIONINSIGHTSRESP = DESCRIPTOR.message_types_by_name['GetOrganizationInsightsResp']
_SNOOZEORGANIZATIONINSIGHTREQ = DESCRIPTOR.message_types_by_name['SnoozeOrganizationInsightReq']
_SNOOZEORGANIZATIONINSIGHTRESP = DESCRIPTOR.message_types_by_name['SnoozeOrganizationInsightResp']
_GETORGANIZATIONMETADATAREQ = DESCRIPTOR.message_types_by_name['GetOrganizationMetadataReq']
_GETORGANIZATIONMETADATARESP = DESCRIPTOR.message_types_by_name['GetOrganizationMetadataResp']
_SETORGANIZATIONMETADATAREQ = DESCRIPTOR.message_types_by_name['SetOrganizationMetadataReq']
_SETORGANIZATIONMETADATARESP = DESCRIPTOR.message_types_by_name['SetOrganizationMetadataResp']
_GETUSERREQ = DESCRIPTOR.message_types_by_name['GetUserReq']
_GETUSERRESP = DESCRIPTOR.message_types_by_name['GetUserResp']
OrganizationInfo = _reflection.GeneratedProtocolMessageType('OrganizationInfo', (_message.Message,), {
  'DESCRIPTOR' : _ORGANIZATIONINFO,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.OrganizationInfo)
  })
_sym_db.RegisterMessage(OrganizationInfo)

GetOrganizationReq = _reflection.GeneratedProtocolMessageType('GetOrganizationReq', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONREQ,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetOrganizationReq)
  })
_sym_db.RegisterMessage(GetOrganizationReq)

GetOrganizationResp = _reflection.GeneratedProtocolMessageType('GetOrganizationResp', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONRESP,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetOrganizationResp)
  })
_sym_db.RegisterMessage(GetOrganizationResp)

GetOrganizationMetricsReq = _reflection.GeneratedProtocolMessageType('GetOrganizationMetricsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONMETRICSREQ,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetOrganizationMetricsReq)
  })
_sym_db.RegisterMessage(GetOrganizationMetricsReq)

GetOrganizationMetricsResp = _reflection.GeneratedProtocolMessageType('GetOrganizationMetricsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONMETRICSRESP,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetOrganizationMetricsResp)
  })
_sym_db.RegisterMessage(GetOrganizationMetricsResp)

GetOrganizationInsightsReq = _reflection.GeneratedProtocolMessageType('GetOrganizationInsightsReq', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONINSIGHTSREQ,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetOrganizationInsightsReq)
  })
_sym_db.RegisterMessage(GetOrganizationInsightsReq)

GetOrganizationInsightsResp = _reflection.GeneratedProtocolMessageType('GetOrganizationInsightsResp', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONINSIGHTSRESP,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetOrganizationInsightsResp)
  })
_sym_db.RegisterMessage(GetOrganizationInsightsResp)

SnoozeOrganizationInsightReq = _reflection.GeneratedProtocolMessageType('SnoozeOrganizationInsightReq', (_message.Message,), {
  'DESCRIPTOR' : _SNOOZEORGANIZATIONINSIGHTREQ,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.SnoozeOrganizationInsightReq)
  })
_sym_db.RegisterMessage(SnoozeOrganizationInsightReq)

SnoozeOrganizationInsightResp = _reflection.GeneratedProtocolMessageType('SnoozeOrganizationInsightResp', (_message.Message,), {
  'DESCRIPTOR' : _SNOOZEORGANIZATIONINSIGHTRESP,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.SnoozeOrganizationInsightResp)
  })
_sym_db.RegisterMessage(SnoozeOrganizationInsightResp)

GetOrganizationMetadataReq = _reflection.GeneratedProtocolMessageType('GetOrganizationMetadataReq', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONMETADATAREQ,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetOrganizationMetadataReq)
  })
_sym_db.RegisterMessage(GetOrganizationMetadataReq)

GetOrganizationMetadataResp = _reflection.GeneratedProtocolMessageType('GetOrganizationMetadataResp', (_message.Message,), {
  'DESCRIPTOR' : _GETORGANIZATIONMETADATARESP,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetOrganizationMetadataResp)
  })
_sym_db.RegisterMessage(GetOrganizationMetadataResp)

SetOrganizationMetadataReq = _reflection.GeneratedProtocolMessageType('SetOrganizationMetadataReq', (_message.Message,), {
  'DESCRIPTOR' : _SETORGANIZATIONMETADATAREQ,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.SetOrganizationMetadataReq)
  })
_sym_db.RegisterMessage(SetOrganizationMetadataReq)

SetOrganizationMetadataResp = _reflection.GeneratedProtocolMessageType('SetOrganizationMetadataResp', (_message.Message,), {
  'DESCRIPTOR' : _SETORGANIZATIONMETADATARESP,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.SetOrganizationMetadataResp)
  })
_sym_db.RegisterMessage(SetOrganizationMetadataResp)

GetUserReq = _reflection.GeneratedProtocolMessageType('GetUserReq', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERREQ,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetUserReq)
  })
_sym_db.RegisterMessage(GetUserReq)

GetUserResp = _reflection.GeneratedProtocolMessageType('GetUserResp', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERRESP,
  '__module__' : 'prodvana.organization.organization_manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.organization.GetUserResp)
  })
_sym_db.RegisterMessage(GetUserResp)

_ORGANIZATIONMANAGER = DESCRIPTOR.services_by_name['OrganizationManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZOgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/organization'
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['class']._options = None
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['class']._serialized_options = b'\372B\005\202\001\002\020\001'
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['duration']._options = None
  _SNOOZEORGANIZATIONINSIGHTREQ.fields_by_name['duration']._serialized_options = b'\372B\007\252\001\004\010\001*\000'
  _SETORGANIZATIONMETADATAREQ.fields_by_name['metadata']._options = None
  _SETORGANIZATIONMETADATAREQ.fields_by_name['metadata']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETUSERREQ.fields_by_name['user_id']._options = None
  _GETUSERREQ.fields_by_name['user_id']._serialized_options = b'\372B\004r\002\020\001'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganization']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganization']._serialized_options = b'\202\323\344\223\002\022\022\020/v1/organization'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetrics']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetrics']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/organization/metrics'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationInsights']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationInsights']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/organization/insights'
  _ORGANIZATIONMANAGER.methods_by_name['SnoozeOrganizationInsight']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['SnoozeOrganizationInsight']._serialized_options = b'\202\323\344\223\002\"\032 /v1/organization/insights/snooze'
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetadata']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetOrganizationMetadata']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/organization/metadata'
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationMetadata']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['SetOrganizationMetadata']._serialized_options = b'\202\323\344\223\002\036\"\031/v1/organization/metadata:\001*'
  _ORGANIZATIONMANAGER.methods_by_name['GetUser']._options = None
  _ORGANIZATIONMANAGER.methods_by_name['GetUser']._serialized_options = b'\202\323\344\223\002#\022!/v1/organization/user/{user_id=*}'
  _ORGANIZATIONINFO._serialized_start=376
  _ORGANIZATIONINFO._serialized_end=588
  _GETORGANIZATIONREQ._serialized_start=590
  _GETORGANIZATIONREQ._serialized_end=610
  _GETORGANIZATIONRESP._serialized_start=612
  _GETORGANIZATIONRESP._serialized_end=696
  _GETORGANIZATIONMETRICSREQ._serialized_start=699
  _GETORGANIZATIONMETRICSREQ._serialized_end=830
  _GETORGANIZATIONMETRICSRESP._serialized_start=832
  _GETORGANIZATIONMETRICSRESP._serialized_end=925
  _GETORGANIZATIONINSIGHTSREQ._serialized_start=927
  _GETORGANIZATIONINSIGHTSREQ._serialized_end=955
  _GETORGANIZATIONINSIGHTSRESP._serialized_start=957
  _GETORGANIZATIONINSIGHTSRESP._serialized_end=1032
  _SNOOZEORGANIZATIONINSIGHTREQ._serialized_start=1035
  _SNOOZEORGANIZATIONINSIGHTREQ._serialized_end=1173
  _SNOOZEORGANIZATIONINSIGHTRESP._serialized_start=1175
  _SNOOZEORGANIZATIONINSIGHTRESP._serialized_end=1206
  _GETORGANIZATIONMETADATAREQ._serialized_start=1208
  _GETORGANIZATIONMETADATAREQ._serialized_end=1236
  _GETORGANIZATIONMETADATARESP._serialized_start=1238
  _GETORGANIZATIONMETADATARESP._serialized_end=1334
  _SETORGANIZATIONMETADATAREQ._serialized_start=1336
  _SETORGANIZATIONMETADATAREQ._serialized_end=1441
  _SETORGANIZATIONMETADATARESP._serialized_start=1443
  _SETORGANIZATIONMETADATARESP._serialized_end=1472
  _GETUSERREQ._serialized_start=1474
  _GETUSERREQ._serialized_end=1512
  _GETUSERRESP._serialized_start=1514
  _GETUSERRESP._serialized_end=1563
  _ORGANIZATIONMANAGER._serialized_start=1566
  _ORGANIZATIONMANAGER._serialized_end=2687
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/meta.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!prodvana/common_config/meta.proto\x12\x16prodvana.common_config\x1a\x1aprodvana/object/meta.proto\"\x89\x01\n\x19ServiceInstanceObjectMeta\x12\x31\n\x0cservice_meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x39\n\x14release_channel_meta\x18\x02 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\"]\n\x15PipelineRunObjectMeta\x12\x32\n\rpipeline_meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12\x10\n\x08run_name\x18\x02 \x01(\tBRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_SERVICEINSTANCEOBJECTMETA = DESCRIPTOR.message_types_by_name['ServiceInstanceObjectMeta']
_PIPELINERUNOBJECTMETA = DESCRIPTOR.message_types_by_name['PipelineRunObjectMeta']
ServiceInstanceObjectMeta = _reflection.GeneratedProtocolMessageType('ServiceInstanceObjectMeta', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINSTANCEOBJECTMETA,
  '__module__' : 'prodvana.common_config.meta_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ServiceInstanceObjectMeta)
  })
_sym_db.RegisterMessage(ServiceInstanceObjectMeta)

PipelineRunObjectMeta = _reflection.GeneratedProtocolMessageType('PipelineRunObjectMeta', (_message.Message,), {
  'DESCRIPTOR' : _PIPELINERUNOBJECTMETA,
  '__module__' : 'prodvana.common_config.meta_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.PipelineRunObjectMeta)
  })
_sym_db.RegisterMessage(PipelineRunObjectMeta)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _SERVICEINSTANCEOBJECTMETA._serialized_start=90
  _SERVICEINSTANCEOBJECTMETA._serialized_end=227
  _PIPELINERUNOBJECTMETA._serialized_start=229
  _PIPELINERUNOBJECTMETA._serialized_end=322
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import prodvana.proto.prodvana.desired_state.manager_pb2

class DesiredStateManagerStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    SetDesiredState: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateResp,
    ]
    GetServiceDesiredStateConvergenceSummary: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateConvergenceSummaryReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateConvergenceSummaryResp,
    ]
    GetServiceLastConvergedStates: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLastConvergedStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLastConvergedStateResp,
    ]
    GetServiceDesiredStateHistory: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateHistoryReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateHistoryResp,
    ]
    GetDesiredState: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateResp,
    ]
    GetDesiredStateConvergenceSummary: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateConvergenceReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateConvergenceSummaryResp,
    ]
    ValidateDesiredState: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.ValidateDesiredStateReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.ValidateDesiredStateResp,
    ]
    SetManualApproval: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.SetManualApprovalReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.SetManualApprovalResp,
    ]
    PromoteDelivery: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.PromoteDeliveryReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.PromoteDeliveryResp,
    ]
    BypassProtection: grpc.UnaryUnaryMultiCallable[
        prodvana.proto.prodvana.desired_state.manager_pb2.BypassProtectionReq,
        prodvana.proto.prodvana.desired_state.manager_pb2.BypassProtectionResp,
    ]

class DesiredStateManagerServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def SetDesiredState(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.SetDesiredStateResp: ...
    @abc.abstractmethod
    def GetServiceDesiredStateConvergenceSummary(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateConvergenceSummaryReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateConvergenceSummaryResp: ...
    @abc.abstractmethod
    def GetServiceLastConvergedStates(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLastConvergedStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceLastConvergedStateResp: ...
    @abc.abstractmethod
    def GetServiceDesiredStateHistory(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateHistoryReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetServiceDesiredStateHistoryResp: ...
    @abc.abstractmethod
    def GetDesiredState(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateResp: ...
    @abc.abstractmethod
    def GetDesiredStateConvergenceSummary(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateConvergenceReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.GetDesiredStateConvergenceSummaryResp: ...
    @abc.abstractmethod
    def ValidateDesiredState(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.ValidateDesiredStateReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.ValidateDesiredStateResp: ...
    @abc.abstractmethod
    def SetManualApproval(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.SetManualApprovalReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.SetManualApprovalResp: ...
    @abc.abstractmethod
    def PromoteDelivery(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.PromoteDeliveryReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.PromoteDeliveryResp: ...
    @abc.abstractmethod
    def BypassProtection(
        self,
        request: prodvana.proto.prodvana.desired_state.manager_pb2.BypassProtectionReq,
        context: grpc.ServicerContext,
    ) -> prodvana.proto.prodvana.desired_state.manager_pb2.BypassProtectionResp: ...

def add_DesiredStateManagerServicer_to_server(servicer: DesiredStateManagerServicer, server: grpc.Server) -> None: ...
